
/**
* Copyright (c) 2000 Symbian Ltd
*/
package com.symbian.devnet.quartz.awt;

import java.awt.*;

/** 
* GridPanel offers a straightforward way to achieve relative positioning of  
* visual components in a Panel. It makes use of a GridBagLayout.
* @author Symbian Devnet
*/
public class GridPanel extends Panel
{
	protected GridBagConstraints constraints;
	private GridBagLayout layout; 
	
	/**
	* Default GridBagConstraints anchor is set to NORTH
	* and its Insets to (2, 2, 2, 2)
	*/
	public GridPanel()
	{
	layout = new GridBagLayout();
	setLayout(layout);
	constraints = new GridBagConstraints();
	constraints.insets = new Insets(2, 2, 2, 2);
	constraints.anchor = GridBagConstraints.NORTH;
	}

	/**
	* Adds specified component to container at specified coordinates. Here (x,y) = (0,0)
	* means top left.
	* @param item Component to be added
	* @param gridx the x-coordinate
	* @param gridy the y-coordinate
	*/
	public void add(Component item, int gridx, int gridy)
	{
		constraints.gridx = gridx;
		constraints.gridy = gridy;
		layout.setConstraints(item, constraints); 
		add(item);
	}

	/**
	* Get the constraints object associated with the LayoutManager of this panel.
	*	@return the constraints object
	*/
	public GridBagConstraints getConstraints()
	{
		return constraints;
	}
		
}